#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hjsmin
version:              0.2.1
visibility:           public
id:                   hjsmin-0.2.1-HlXBRWua0dF9jgOEO3zYA2
key:                  hjsmin-0.2.1-HlXBRWua0dF9jgOEO3zYA2
license:              BSD-3-Clause
maintainer:           Erik de Castro Lopo <erikd@mega-nerd.com>
author:               Alan Zimmerman <alan.zimm@gmail.com>
stability:            unstable
homepage:             http://github.com/erikd/hjsmin
synopsis:             Haskell implementation of a javascript minifier
description:
    Reduces size of javascript files by stripping out extraneous whitespace and
    other syntactic elements, without changing the semantics.

category:             Web
abi:                  8edfbb940586739838e8294e2ea88646
exposed:              True
exposed-modules:      Text.Jasmine
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hjsmin-0.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hjsmin
hs-libraries:         HShjsmin-0.2.1-HlXBRWua0dF9jgOEO3zYA2
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    language-javascript-0.7.1.0-ELJvBOEFd4yEHCx0pzz4jJ text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
haddock-html:         /usr/share/doc/haskell-hjsmin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

